==> devextreme-21.2.1-alpha-21200-0321.tgz: package/renovation/component_wrapper/navigation/scroll_view.js <==
/**
 * DevExtreme (renovation/component_wrapper/navigation/scroll_view.js)
 * Version: 21.2.0 (build 21200-0321)
 * Build date: Mon Jul 19 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.ScrollViewWrapper = void 0;
var _component = _interopRequireDefault(require("../common/component"));
var _deferred = require("../../../core/utils/deferred");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var ScrollViewWrapper = function(_Component) {
    _inheritsLoose(ScrollViewWrapper, _Component);

    function ScrollViewWrapper() {
        return _Component.apply(this, arguments) || this
    }
    var _proto = ScrollViewWrapper.prototype;
    _proto.update = function() {
        this.viewRef.updateHandler();
        return (new _deferred.Deferred).resolve()
    };
    _proto.release = function(preventScrollBottom) {
        this.viewRef.release(preventScrollBottom);
        return (new _deferred.Deferred).resolve()
    };
    _proto._optionChanged = function(option) {
        var name = option.name;
        if ("useNative" === name) {
            this._isNodeReplaced = false
        }
        _Component.prototype._optionChanged.call(this, option)
    };
    return ScrollViewWrapper
}(_component.default);
exports.ScrollViewWrapper = ScrollViewWrapper;

==> devextreme-22.1.1-alpha-21357-0315.tgz: package/renovation/component_wrapper/navigation/scroll_view.js <==
/**
 * DevExtreme (renovation/component_wrapper/navigation/scroll_view.js)
 * Version: 22.1.0 (build 21357-0315)
 * Build date: Thu Dec 23 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.ScrollViewWrapper = void 0;
var _component = _interopRequireDefault(require("../common/component"));
var _deferred = require("../../../core/utils/deferred");

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var ScrollViewWrapper = function(_Component) {
    _inheritsLoose(ScrollViewWrapper, _Component);

    function ScrollViewWrapper() {
        return _Component.apply(this, arguments) || this
    }
    var _proto = ScrollViewWrapper.prototype;
    _proto.update = function() {
        var _this$viewRef;
        null === (_this$viewRef = this.viewRef) || void 0 === _this$viewRef ? void 0 : _this$viewRef.updateHandler();
        return (0, _deferred.Deferred)().resolve()
    };
    _proto.release = function(preventScrollBottom) {
        this.viewRef.release(preventScrollBottom);
        return (0, _deferred.Deferred)().resolve()
    };
    _proto._dimensionChanged = function() {
        var _this$viewRef2;
        null === (_this$viewRef2 = this.viewRef) || void 0 === _this$viewRef2 ? void 0 : _this$viewRef2.updateHandler()
    };
    _proto.isRenovated = function() {
        return !!_component.default.IS_RENOVATED_WIDGET
    };
    _proto._optionChanged = function(option) {
        var name = option.name;
        if ("useNative" === name) {
            this._isNodeReplaced = false
        }
        _Component.prototype._optionChanged.call(this, option)
    };
    return ScrollViewWrapper
}(_component.default);
exports.ScrollViewWrapper = ScrollViewWrapper;
